function [data, auxData, metaData, txtData, weights] = mydata_Lumbricus_terrestris

%% set metaData
metaData.phylum     = 'Annelida'; 
metaData.class      = 'Clitellata'; 
metaData.order      = 'Haplotaxida'; 
metaData.family     = 'Lumbricidae';
metaData.species    = 'Lumbricus_terrestris'; 
metaData.species_en = 'Common earthworm'; 
metaData.T_typical  = C2K(20); % K, body temp
metaData.data_0     = {'ab_T'; 'ap'; 'am'; 'Li'; 'Ww0'; 'Wwb'; 'Wwp'; 'Wwi'}; 
metaData.data_1     = {'t-Ww'; 't-N'}; 

metaData.COMPLETE = 2.7; % using criteria of LikaKear2011

metaData.author   = {'Bas Kooijman'};    
metaData.date_subm = [2013 05 01];              
metaData.email    = {'bas.kooijman@vu.nl'};            
metaData.address  = {'VU University Amsterdam'};   

metaData.curator     = {'Starrlight Augustine'};
metaData.email_cur   = {'sta@akvaplan.niva.no'}; 
metaData.date_acc    = [2015 12 07]; 


%% set data
% zero-variate data

data.ab_15 = 90;  units.ab_15 = 'd'; label.ab_15 = 'age at birth';         bibkey.ab_15 = 'Butt1993';   
  temp.ab_15 = C2K(15); units.temp.ab_15 = 'K'; label.temp.ab_15 = 'temperature';
data.ab_20 = 70;  units.ab_20 = 'd'; label.ab_20 = 'age at birth';         bibkey.ab_20 = 'Butt1993';   
  temp.ab_20 = C2K(20); units.temp.ab_20 = 'K'; label.temp.ab_20 = 'temperature';
data.tp = 3*30.5; units.tp = 'd';    label.tp = 'time since birth at puberty'; bibkey.tp = 'Butt1993';
  temp.tp = C2K(20);    units.temp.tp = 'K'; label.temp.tp = 'temperature';
data.am = 8*365;  units.am = 'd';    label.am = 'life span';               bibkey.am = 'guessed';   
  temp.am = C2K(20);    units.temp.am = 'K'; label.temp.am = 'temperature'; 

data.Li  = 22.5;  units.Li  = 'cm';  label.Li  = 'ultimate total length';  bibkey.Li  = 'Wiki';

data.Ww0 = 0.061; units.Ww0 = 'g';   label.Ww0 = 'egg wet weight';         bibkey.Ww0 = 'Butt1993';
data.Wwb = 0.038; units.Wwb = 'g';   label.Wwb = 'wet weight at birth';    bibkey.Wwb = 'Butt1993';
data.Wwp = 5.0;   units.Wwp = 'g';   label.Wwp = 'wet weight at puberty';  bibkey.Wwp = 'Butt1993';
data.Wwi = 7;     units.Wwi = 'g';   label.Wwi = 'ultimate wet weight';    bibkey.Wwi = 'Butt1993';
  
 
% uni-variate data

% tW-data from Butt1993 at 20 C
data.tW = [ ... % time since birth (d), wet weight (g)
  0.464	0.067
 31.520	1.231
 60.722	3.429
 91.778	4.930
121.444	6.094
152.500	6.337];
units.tW   = {'d', 'g'};  label.tW = {'time since birth', 'wet weight'};  
temp.tW    = C2K(20);  units.temp.tW = 'K'; label.temp.tW = 'temperature';
bibkey.tW = 'Butt1993';
%
data.tN = [ ... % time after maturation (d), cumulative offspring (#)
29.483	4.440
62.260	8.096
91.715	12.201
122.243	15.748
152.827	19.963
181.106	23.400
213.789	25.943
243.160	29.044
274.676	31.031
303.982	33.353
336.608	35.227
365.970	38.217];
units.tN   = {'d', '#'};  label.tN = {'time since birth', 'cumulative offspring'};  
temp.tN    = C2K(20);  units.temp.tN = 'K'; label.temp.tN = 'temperature';
bibkey.tN = 'Butt1993';
comment.tN = 'initial mass 3.1 g; decreasing mass during reprod to 5.3 g';
  
%% set weights for all real data
weights = setweights(data, []);

%% set pseudodata and respective weights
[data, units, label, weights] = addpseudodata(data, units, label, weights);

%% pack auxData and txtData for output
auxData.temp = temp;
txtData.units = units;
txtData.label = label;
txtData.bibkey = bibkey;
txtData.comment = comment;

%% Discussion points
D1 = 'Reproduction efficiency kap_R has been set to 0.95/2 because the species is simultaneous hermaphroditic';
metaData.discussion = struct('D1', D1);

%% References
bibkey = 'Wiki'; type = 'Misc'; bib = ...
'howpublished = {\url{http://en.wikipedia.org/wiki/Lumbricus_terrestris}}';
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];
%
bibkey = 'Kooy2010'; type = 'Book'; bib = [ ...  % used in setting of chemical parameters and pseudodata
'author = {Kooijman, S.A.L.M.}, ' ...
'year = {2010}, ' ...
'title  = {Dynamic Energy Budget theory for metabolic organisation}, ' ...
'publisher = {Cambridge Univ. Press, Cambridge}, ' ...
'pages = {Table 4.2 (page 150), 8.1 (page 300)}, ' ...
'howpublished = {\url{http://www.bio.vu.nl/thb/research/bib/Kooy2010.html}}'];
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];
%
bibkey = 'Butt1993'; type = 'Article'; bib = [ ... 
'author = {Butt, K. R.}, ' ... 
'year = {1993}, ' ...
'title = {Reproduction and growth of three deep-burrowing earthworms ({L}umbricidae) in laboratory culture in order to assess production for soil restoration}, ' ...
'journal = {Biol Fertil Soils}, ' ...
'volume = {16}, ' ...
'pages = {135--138}'];
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];
%
bibkey = 'HolmOste1991'; type = 'Article'; bib = [ ... 
'author = {Holmstrup, M. and {\O}stergaard, I. K. and Nielsen, A. and Hansen, B. T.}, ' ... 
'year = {1991}, ' ...
'title = {The relationship between temperature and cocoon incubation time for some Lumbricid earthworm species}, ' ...
'journal = {edobiologia}, ' ...
'volume = {35}, ' ...
'pages = {179--184}'];
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];
